@@ -1,13 +1,14 @@
 # -*- coding: utf-8 -*-
 
-############################ Copyrights and license ############################
+# ########################## Copyrights and license ############################
 #                                                                              #
 # Copyright 2012 Vincent Jacques <vincent@vincent-jacques.net>                 #
 # Copyright 2012 Zearin <zearin@gonk.net>                                      #
 # Copyright 2013 Stuart Glaser <stuglaser@gmail.com>                           #
 # Copyright 2013 Vincent Jacques <vincent@vincent-jacques.net>                 #
 #                                                                              #
-# This file is part of PyGithub. http://jacquev6.github.com/PyGithub/          #
+# This file is part of PyGithub.                                               #
+# http://pygithub.github.io/PyGithub/v1/index.html                             #
 #                                                                              #
 # PyGithub is free software: you can redistribute it and/or modify it under    #
 # the terms of the GNU Lesser General Public License as published by the Free  #
@@ -22,7 +23,7 @@
 # You should have received a copy of the GNU Lesser General Public License     #
 # along with PyGithub. If not, see <http://www.gnu.org/licenses/>.             #
 #                                                                              #
-################################################################################
+# ##############################################################################
 
 import Framework
 
@@ -57,6 +58,9 @@ class Issue(Framework.TestCase):
         self.assertEqual(self.issue.user.login, "jacquev6")
         self.assertEqual(self.issue.repository.name, "PyGithub")
 
+        # test __repr__() based on this attributes
+        self.assertEqual(self.issue.__repr__(), 'Issue(title="Issue created by PyGithub", number=28)')
+
     def testEditWithoutParameters(self):
         self.issue.edit()
 
@@ -87,6 +91,9 @@ class Issue(Framework.TestCase):
     def testGetComments(self):
         self.assertListKeyEqual(self.issue.get_comments(), lambda c: c.user.login, ["jacquev6", "roskakori"])
 
+    def testGetCommentsSince(self):
+        self.assertListKeyEqual(self.issue.get_comments(datetime.datetime(2012, 5, 26, 13, 59, 33)), lambda c: c.user.login, ["jacquev6", "roskakori"])
+
     def testGetEvents(self):
         self.assertListKeyEqual(self.issue.get_events(), lambda e: e.id, [15819975, 15820048])
 
@@ -104,6 +111,17 @@ class Issue(Framework.TestCase):
         self.issue.add_to_labels(bug, question)
         self.assertListKeyEqual(self.issue.get_labels(), lambda l: l.name, ["Bug", "Project management", "Question"])
 
+    def testAddAndRemoveLabelsWithStringArguments(self):
+        bug = "Bug"
+        question = "Question"
+        self.assertListKeyEqual(self.issue.get_labels(), lambda l: l.name, ["Bug", "Project management", "Question"])
+        self.issue.remove_from_labels(bug)
+        self.assertListKeyEqual(self.issue.get_labels(), lambda l: l.name, ["Project management", "Question"])
+        self.issue.remove_from_labels(question)
+        self.assertListKeyEqual(self.issue.get_labels(), lambda l: l.name, ["Project management"])
+        self.issue.add_to_labels(bug, question)
+        self.assertListKeyEqual(self.issue.get_labels(), lambda l: l.name, ["Bug", "Project management", "Question"])
+
     def testDeleteAndSetLabels(self):
         bug = self.repo.get_label("Bug")
         question = self.repo.get_label("Question")
@@ -112,3 +130,12 @@ class Issue(Framework.TestCase):
         self.assertListKeyEqual(self.issue.get_labels(), None, [])
         self.issue.set_labels(bug, question)
         self.assertListKeyEqual(self.issue.get_labels(), lambda l: l.name, ["Bug", "Question"])
+
+    def testDeleteAndSetLabelsWithStringArguments(self):
+        bug = "Bug"
+        question = "Question"
+        self.assertListKeyEqual(self.issue.get_labels(), lambda l: l.name, ["Bug", "Project management", "Question"])
+        self.issue.delete_labels()
+        self.assertListKeyEqual(self.issue.get_labels(), None, [])
+        self.issue.set_labels(bug, question)
+        self.assertListKeyEqual(self.issue.get_labels(), lambda l: l.name, ["Bug", "Question"])
